{ pkgs, lib, ... }:
let
  nixvim = import (builtins.fetchGit {
    url = "https://github.com/nix-community/nixvim";
    ref = "nixos-23.05";
  });
in
{
  imports = [
    nixvim.homeManagerModules.nixvim
  ];

  programs.nixvim = {
    enable = true;
    colorschemes.base16 = {
      # FIXME Dynamic... or use stylix
      enable = true;
      colorscheme = "solarized-light";

    };
    plugins = {
      # Catches attention when cursor changed position
      # TODO Unmapped, do I still want to use it?
      specs = {
        enable = true;
        min_jump = 5;
      };

      # Tabline
      barbar.enable = true;
    };
    extraPlugins = with pkgs.vimPlugins; [
      nvim-scrollview
    ];
    # 23.11: Use keymaps, seems better
    maps = {
      # barbar
      normal."<C-H>" = { action = "<Cmd>BufferPrevious<CR>"; silent = true; };
      normal."<C-L>" = { action = "<Cmd>BufferNext<CR>"; silent = true; };
      # TODO https://www.reddit.com/r/neovim/comments/mbj8m5/how_to_setup_ctrlshiftkey_mappings_in_neovim_and/
      normal."<Space><C-H>" = { action = "<Cmd>BufferMovePrevious<CR>"; silent = true; };
      normal."<Space><C-L>" = { action = "<Cmd>BufferMoveNext<CR>"; silent = true; };
      # TODO gotos don't work
      normal."<C-1>" = { action = "<Cmd>BufferGoto 1<CR>"; silent = true; };
      normal."<C-2>" = { action = "<Cmd>BufferGoto 2<CR>"; silent = true; };
      normal."<C-3>" = { action = "<Cmd>BufferGoto 3<CR>"; silent = true; };
      normal."<C-4>" = { action = "<Cmd>BufferGoto 4<CR>"; silent = true; };
      normal."<C-5>" = { action = "<Cmd>BufferGoto 5<CR>"; silent = true; };
      normal."<C-6>" = { action = "<Cmd>BufferGoto 6<CR>"; silent = true; };
      normal."<C-7>" = { action = "<Cmd>BufferGoto 7<CR>"; silent = true; };
      normal."<C-8>" = { action = "<Cmd>BufferGoto 8<CR>"; silent = true; };
      normal."<C-9>" = { action = "<Cmd>BufferGoto 9<CR>"; silent = true; };
      normal."<C-0>" = { action = "<Cmd>BufferLast<CR>"; silent = true; };
      normal."gb" = { action = "<Cmd>BufferPick<CR>"; silent = true; };
      # TODO Other useful options?

    };
  };
}
